# Warning
This folder contains credentials, such as .session, this **can be used to access your telegram account**<br><br>
To get api\_id and api\_hash, go [here](https://my.telegram.org/auth?to=apps)
